::: {{cookiecutter.project_slug}}

## Configuration

::: {{cookiecutter.project_slug}}.config

## Core

::: {{cookiecutter.project_slug}}.core

## Constants

::: {{cookiecutter.project_slug}}.constants

## Logger

::: {{cookiecutter.project_slug}}.logger

## Utils

::: {{cookiecutter.project_slug}}.utils

## Exceptions

::: {{cookiecutter.project_slug}}.exception

## Entities

::: {{cookiecutter.project_slug}}.entity

## Models

::: {{cookiecutter.project_slug}}.models

## Services

::: {{cookiecutter.project_slug}}.services

## APIs

::: {{cookiecutter.project_slug}}.api
